# pysportsref
Utils for scraping/working with sports reference data.

Why is the difference between this package and other sports reference scraping packages?
This package is also focused on the analysis part. So not only will this package provide utils for pulling down data,
but it will also provide some functions for manipulating that data, and finding insights.also

### How to install
This package is easily installable with pip: `pip install pysportsref`

### How to contribute
We are hoping people contribute to this package! Whether it is through adding functions or adding example notebooks,
anything is welcome! There are two ways we envision people contributing:

1. Making pull requests: pretty self explanatory, if you have a change you want to see feel free to open a PR!
1. Opening an issue: if you want something done, whether it be a util or an example/type of analysis, open an issue
and we will try to get it!
